import { useTranslation } from "next-i18next";

import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
import useWidgetAPI from "utils/proxy/use-widget-api";

export default function Component({ service }) {
  const { t } = useTranslation();
  const { widget } = service;
  const { data, error } = useWidgetAPI(widget, "widget", {
    refreshInterval: 5000,
  });

  if (error) {
    return <Container service={service} error={error} />;
  }

  if (!data) {
    return (
      <Container service={service}>
        <Block label="Response Time" />
        <Block label="Stored Keys" />
        <Block label="Indexed Lyrics" />
        <Block label="Stored Sessions" />
      </Container>
    );
  }

  return (
    <Container service={service}>
      <Block label="Response Time" value={`${data.responseTime}s` } />
      <Block label="Stored Keys" value={t("common.number", { value: data.storedKeys })} />
      <Block label="Indexed Lyrics" value={t("common.number", { value: data.indexedLyrics })} />
      <Block label="Stored Sessions" value={t("common.number", { value: data.sessions })} />
    </Container>
  );
}

